package org.rcisoft.business.sysScheduledTaskLog.controller;


/*固定导入*/
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.Operation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import jakarta.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.sysScheduledTaskLog.entity.SysScheduledTaskLog;
import org.rcisoft.business.sysScheduledTaskLog.service.SysScheduledTaskLogService;

import java.util.List;

/**
* Created by cy on 2025年2月20日 上午11:14:19.
*/
@RestController
@RequestMapping("/sysscheduledtasklog")
public class SysScheduledTaskLogController extends CyPaginationController<SysScheduledTaskLog> {


    @Autowired
    private SysScheduledTaskLogService sysScheduledTaskLogServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:add')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-新增SysScheduledTaskLog", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加SysScheduledTaskLog", description="添加SysScheduledTaskLog")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysScheduledTaskLog sysScheduledTaskLog, BindingResult bindingResult) {
        CyPersistModel data = sysScheduledTaskLogServiceImpl.persist(sysScheduledTaskLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysScheduledTaskLog);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:delete')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-删除SysScheduledTaskLog", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除SysScheduledTaskLog", description="删除SysScheduledTaskLog")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,SysScheduledTaskLog sysScheduledTaskLog) {
        sysScheduledTaskLog.setBusinessId(businessId);
        CyPersistModel data = sysScheduledTaskLogServiceImpl.remove(sysScheduledTaskLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:update')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-修改SysScheduledTaskLog", businessType = CyLogTypeEnum.UPDATE)
    @Operation(summary="修改SysScheduledTaskLog", description="修改SysScheduledTaskLog")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = false,  schema = @Schema(type = "string"))})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid SysScheduledTaskLog sysScheduledTaskLog, BindingResult bindingResult) {
        sysScheduledTaskLog.setBusinessId(businessId);
        CyPersistModel data = sysScheduledTaskLogServiceImpl.merge(sysScheduledTaskLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysScheduledTaskLog);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:query')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-查询SysScheduledTaskLog", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一SysScheduledTaskLog", description="查询单一SysScheduledTaskLog")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysScheduledTaskLogServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:list')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-查询SysScheduledTaskLog", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询SysScheduledTaskLog集合", description="查询SysScheduledTaskLog集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(SysScheduledTaskLog sysScheduledTaskLog) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysScheduledTaskLogServiceImpl.findAll(sysScheduledTaskLog));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:scheduledTaskLog:list')")
    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-查询SysScheduledTaskLog", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询SysScheduledTaskLog集合", description="分页查询SysScheduledTaskLog集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(SysScheduledTaskLog sysScheduledTaskLog) {
        sysScheduledTaskLogServiceImpl.findAllByPagination(getPaginationUtility(), sysScheduledTaskLog);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-SysScheduledTaskLog管理-查询SysScheduledTaskLog", businessType = CyLogTypeEnum.EXPORT)
    @Operation(summary = "导出SysScheduledTaskLog信息", description = "导出SysScheduledTaskLog信息")
    @GetMapping(value = "/export")
    public void outSysScheduledTaskLog(HttpServletResponse response,SysScheduledTaskLog sysScheduledTaskLog,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="SysScheduledTaskLog信息.xls";break;
            case "1": excelName="SysScheduledTaskLog信息.xlsx";break;
            case "2": excelName="SysScheduledTaskLog信息.csv";break;
        }
        List<SysScheduledTaskLog> sysScheduledTaskLogList = sysScheduledTaskLogServiceImpl.export(sysScheduledTaskLog);
        CyEpExcelUtil.exportExcel(sysScheduledTaskLogList, "SysScheduledTaskLog信息", "SysScheduledTaskLog信息", SysScheduledTaskLog.class, excelName, response);
    }
}
